==> haskell-wl-pprint-extras-3.5.0.5-102-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-extras
version: 3.5.0.5
id: wl-pprint-extras-3.5.0.5-Hj60QWlxc7jEm3RE0AS407
key: wl-pprint-extras-3.5.0.5-Hj60QWlxc7jEm3RE0AS407
license: BSD-3-Clause
copyright: Copyright (C) 2011-2012 Edward A. Kmett,
           Copyright (C) 2000 Daan Leijen
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-extras/
synopsis: A free monad based on the Wadler/Leijen pretty printer
description:
    A free monad based on the Wadler/Leijen pretty printer
category: Control, Monads, Text
abi: c16f4fae0324a0bc35f719aafab361d0
exposed: True
exposed-modules:
    Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-extras-3.5.0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wl-pprint-extras-3.5.0.5
hs-libraries: HSwl-pprint-extras-3.5.0.5-Hj60QWlxc7jEm3RE0AS407
depends:
    base-4.12.0.0 containers-0.6.0.1
    semigroupoids-5.3.2-8PTnGnD8ohcIn54HVGc9tA text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-extras-3.5.0.5-103-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-extras
version: 3.5.0.5
id: wl-pprint-extras-3.5.0.5-PuCpx3Oz0xFDWCmYCn6e4
key: wl-pprint-extras-3.5.0.5-PuCpx3Oz0xFDWCmYCn6e4
license: BSD-3-Clause
copyright: Copyright (C) 2011-2012 Edward A. Kmett,
           Copyright (C) 2000 Daan Leijen
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-extras/
synopsis: A free monad based on the Wadler/Leijen pretty printer
description:
    A free monad based on the Wadler/Leijen pretty printer
category: Control, Monads, Text
abi: 0b750ac4f8ad8ac3e173ff4a8936bcf1
exposed: True
exposed-modules:
    Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-extras-3.5.0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wl-pprint-extras-3.5.0.5
hs-libraries: HSwl-pprint-extras-3.5.0.5-PuCpx3Oz0xFDWCmYCn6e4
depends:
    base-4.12.0.0 containers-0.6.0.1
    semigroupoids-5.3.2-EabV9fVpEFK84rGceeUuvg text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
